PluralRules class

Handles pluralization rules for different languages according to CLDR standards

Constructors

PluralRules()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getPluralCategory(int value, String? locale) PluralCategory
Determines the appropriate plural category for a given value and locale
getPluralFormCount(String languageCode) int
Gets the number of plural forms for a given language
getSupportedLanguages() List<String>
Gets all supported language codes